@@ -323,7 +323,7 @@ gedit_document_init (GeditDocument *document)
 				gedit_encoding_get_charset (enc));
 
 	gedit_document_set_max_undo_levels (document,
-					    gedit_prefs_manager_get_undo_actions_limit ());    
+					    gedit_prefs_manager_get_undo_actions_limit ());
 
 	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (document), FALSE);
 }
@@ -639,7 +639,7 @@ gedit_document_get_uri (const GeditDocument* doc)
 	{
 		gchar *res;
 
-		res = eel_format_uri_for_display (doc->priv->uri);
+		res = gnome_vfs_format_uri_for_display (doc->priv->uri);
 		g_return_val_if_fail (res != NULL, g_strdup (_("Invalid file name")));
 		
 		return res;
@@ -1366,6 +1366,30 @@ gedit_document_is_untouched (const GeditDocument *doc)
 		(!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)));
 }
 
+/* FIXME: Remove this function when gnome-vfs will add an equivalent public
+   function - Paolo (Mar 05, 2004) */
+static gchar *
+get_slow_mime_type (const char *text_uri)
+{
+	GnomeVFSFileInfo *info;
+	char *mime_type;
+	GnomeVFSResult result;
+
+	info = gnome_vfs_file_info_new ();
+	result = gnome_vfs_get_file_info (text_uri, info,
+					  GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+					  GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE |
+					  GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+	if (info->mime_type == NULL || result != GNOME_VFS_OK) {
+		mime_type = NULL;
+	} else {
+		mime_type = g_strdup (info->mime_type);
+	}
+	gnome_vfs_file_info_unref (info);
+
+	return mime_type;
+}
+
 static void
 gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 {
@@ -1382,8 +1406,6 @@ gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 
 	if (doc->priv->uri != NULL)
 		g_free (doc->priv->uri);
-		
-	g_return_if_fail (uri != NULL);
 
 	doc->priv->uri = g_strdup (uri);
 
@@ -1393,10 +1415,12 @@ gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 		doc->priv->untitled_number = 0;
 	}
 
-	data = gedit_metadata_manager_get (uri,
-					   "language");
+	data = gedit_metadata_manager_get (uri, "language");
+
 	if (data != NULL)
 	{
+		gedit_debug (DEBUG_DOCUMENT, "Language: %s", data);
+
 		if (strcmp (data, "_NORMAL_") == 0)
 			language = NULL;
 		else
@@ -1412,12 +1436,14 @@ gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 	{
 		gchar *mime_type;
 
-		mime_type = gnome_vfs_get_mime_type (uri);
+		mime_type = get_slow_mime_type (uri);
 	
 		if (mime_type != NULL)
 		{
 			GtkSourceLanguage *language;
 			
+			gedit_debug (DEBUG_DOCUMENT, "MIME-TYPE: %s", mime_type);
+
 			language = gtk_source_languages_manager_get_language_from_mime_type (
 						gedit_get_languages_manager (),
 						mime_type);
@@ -1430,6 +1456,8 @@ gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 		{
 			g_warning ("Couldn't get mime type for file `%s'", uri);
 		}
+
+		
 	}
 
 	g_signal_emit (G_OBJECT (doc), document_signals[NAME_CHANGED], 0);
@@ -2669,7 +2697,8 @@ gedit_document_set_language (GeditDocument *doc, GtkSourceLanguage *lang)
 	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
 
 	if (lang != NULL)
-		gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (doc), TRUE);
+		gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (doc),
+						 gedit_prefs_manager_get_enable_syntax_highlighting ());
 	else
 		gtk_source_buffer_set_highlight (GTK_SOURCE_BUFFER (doc), FALSE);
 
